orca r4028 - in trunk: . src/orca/scripts/apps/pidgin



Author: joanied
Date: Fri Jul 11 18:27:51 2008
New Revision: 4028
URL: http://svn.gnome.org/viewvc/orca?rev=4028&view=rev

Log:
* src/orca/scripts/apps/pidgin/script.py:
  Additional fix for bug #525656 - Orca needs to handle the new
  Pidgin typing status updates. This was needed due to a change
  in Pidgin.


Modified:
   trunk/ChangeLog
   trunk/src/orca/scripts/apps/pidgin/script.py

Modified: trunk/src/orca/scripts/apps/pidgin/script.py
==============================================================================
--- trunk/src/orca/scripts/apps/pidgin/script.py	(original)
+++ trunk/src/orca/scripts/apps/pidgin/script.py	Fri Jul 11 18:27:51 2008
@@ -756,12 +756,15 @@
             # If the user doesn't want announcements for when their buddies
             # are typing (or have stopped typing), and this is such a message,
             # then just return. The only reliable way to identify such text
             # is by the scale.  We also want to store the last message because
             # msn seems to be sending a constant stream of "is typing" updates.
             #
             attr, start, end = \
                 self.getTextAttributes(event.source, event.detail1)
-            if float(attr.get('scale', '1')) < 1:
+            if float(attr.get('scale', '1')) < 1 \
+               or int(attr.get('weight', '400')) < 400:
                 if not script_settings.announceBuddyTyping or \
                        self.lastStatus == message:
                     return
@@ -756,12 +756,15 @@
             # are typing (or have stopped typing), and this is such a message,
             # then just return. The only reliable way to identify such text
-            # is by the scale.  We also want to store the last message because
-            # msn seems to be sending a constant stream of "is typing" updates.
+            # is by the scale.  This attribute seems to have been removed by
+            # pidgin, so we'll also check the weight.  We also want to store
+            # the last message because msn seems to be sending a constant
+            # stream of "is typing" updates.
             #
             attr, start, end = \



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]